@@ -28,29 +28,33 @@ end
 function get_f_and_df_prepared!(
         df, f::F, ::AutoEnzyme{M, <:AnyDuplicated}, ::Val{B}
     ) where {F, M, B}
-    #=
-    It is not obvious why we don't need a `make_zero` here, in the case of mutable constant data in `f`.
-    - In forward mode, `df` is never incremented if `f` is not mutated, so it remains equal to its initial value of `0`.
-    - In reverse mode, `df` gets incremented but it does not influence the input cotangent `dx`.
-    =#
-    if B == 1
-        return Duplicated(f, df)
+    if isnothing(df)
+        return Const(f)
     else
-        return BatchDuplicated(f, df)
+        if B == 1
+            return Duplicated(f, df)
+        else
+            return BatchDuplicated(f, df)
+        end
     end
 end
 
 function function_shadow(
-        ::F, ::AutoEnzyme{M, <:Union{Const, Nothing}}, ::Val{B}
+        ::F, ::AutoEnzyme{M, <:Union{Const, Nothing}}, ::Mode, ::Val{B}
     ) where {M, B, F}
     return nothing
 end
 
-function function_shadow(f::F, ::AutoEnzyme{M, <:AnyDuplicated}, ::Val{B}) where {F, M, B}
-    if B == 1
-        return make_zero(f)
+function function_shadow(f::F, ::AutoEnzyme{M, <:AnyDuplicated}, mode::Mode, ::Val{B}) where {F, M, B}
+    IA = guess_activity(F, mode)
+    return if IA <: Const
+        nothing
     else
-        return ntuple(_ -> make_zero(f), Val(B))
+        if B == 1
+            return make_zero(f)
+        else
+            return ntuple(_ -> make_zero(f), Val(B))
+        end
     end
 end
 
@@ -87,13 +91,13 @@ function _shadow(
 end
 
 function _shadow(
-        backend::AutoEnzyme{M, <:Union{Const, Nothing}},
-        ::Mode,
+        backend::AutoEnzyme,
+        mode::Mode,
         ::Val{B},
         c_wrapped::DI.FunctionContext,
-    ) where {M, B}
+    ) where {B}
     f = DI.unwrap(c_wrapped)
-    return function_shadow(f, backend, Val(B))
+    return function_shadow(f, backend, mode, Val(B))
 end
 
 function make_context_shadows(
@@ -122,11 +126,6 @@ end
 function _translate_prepared!(
         dc, c_wrapped::Union{DI.ConstantOrCache, DI.FunctionContext}, ::Val{B}
     ) where {B}
-    #=
-    It is not obvious why we don't need a `make_zero` here, in the case of mutable constant contexts.
-    - In forward mode, `dc` is never incremented because `c` is not mutated, so it remains equal to its initial value of `0`.
-    - In reverse mode, `dc` gets incremented but it does not influence the input cotangent `dx`.
-    =#
     c = DI.unwrap(c_wrapped)
     if isnothing(dc)
         return Const(c)
