@@ -1,11 +1,11 @@
 ## Pushforward
 
-struct MooncakeTwoArgPushforwardPrep{SIG, Tcache, DX, DY, FT, CT} <: DI.PushforwardPrep{SIG}
+struct MooncakeTwoArgPushforwardPrep{SIG, Tcache, FT0, FT, YT, CT} <: DI.PushforwardPrep{SIG}
     _sig::Val{SIG}
     cache::Tcache
-    dx_righttype::DX
-    dy_righttype::DY
+    dcall::FT0
     df!::FT
+    dy::YT
     context_tangents::CT
 end
 
@@ -21,18 +21,18 @@ function DI.prepare_pushforward_nokwarg(
     _sig = DI.signature(f!, y, backend, x, tx, contexts...; strict)
     config = get_config(backend)
     cache = prepare_derivative_cache(
+        call_and_return,
         f!,
         y,
         x,
         map(DI.unwrap, contexts)...;
-        config.debug_mode,
-        config.silence_debug_messages,
+        config
     )
-    dx_righttype = zero_tangent(x)
-    dy_righttype = zero_tangent(y)
-    df! = zero_tangent(f!)
+    dcall = zero_tangent_or_primal(call_and_return, backend)
+    df! = zero_tangent_or_primal(f!, backend)
+    dy = zero_tangent_or_primal(y, backend)
     context_tangents = map(zero_tangent_unwrap, contexts)
-    prep = MooncakeTwoArgPushforwardPrep(_sig, cache, dx_righttype, dy_righttype, df!, context_tangents)
+    prep = MooncakeTwoArgPushforwardPrep(_sig, cache, dcall, df!, dy, context_tangents)
     return prep
 end
 
@@ -47,18 +47,15 @@ function DI.value_and_pushforward(
     ) where {F, C, X}
     DI.check_prep(f!, y, prep, backend, x, tx, contexts...)
     ty = map(tx) do dx
-        dx_righttype =
-            dx isa tangent_type(X) ? dx : _copy_to_output!!(prep.dx_righttype, dx)
-        y_dual = zero_dual(y)
-        value_and_derivative!!(
+        _, new_dy = value_and_derivative!!(
             prep.cache,
-            Dual(f!, prep.df!),
-            y_dual,
-            Dual(x, dx_righttype),
-            map(Dual_unwrap, contexts, prep.context_tangents)...,
+            (call_and_return, prep.dcall),
+            (f!, prep.df!),
+            (y, prep.dy),
+            (x, dx),
+            map(first_unwrap, contexts, prep.context_tangents)...,
         )
-        dy = _copy_output(tangent(y_dual))
-        return dy
+        return _copy_output(new_dy)
     end
     return y, ty
 end
@@ -88,18 +85,15 @@ function DI.value_and_pushforward!(
     ) where {F, C, X, Y}
     DI.check_prep(f!, y, prep, backend, x, tx, contexts...)
     foreach(tx, ty) do dx, dy
-        dx_righttype =
-            dx isa tangent_type(X) ? dx : _copy_to_output!!(prep.dx_righttype, dx)
-        dy_righttype =
-            dy isa tangent_type(Y) ? dy : _copy_to_output!!(prep.dy_righttype, dy)
-        value_and_derivative!!(
+        _, new_dy = value_and_derivative!!(
             prep.cache,
-            Dual(f!, prep.df!),
-            Dual(y, dy_righttype),
-            Dual(x, dx_righttype),
-            map(Dual_unwrap, contexts, prep.context_tangents)...,
+            (call_and_return, prep.dcall),
+            (f!, prep.df!),
+            (y, dy),
+            (x, dx),
+            map(first_unwrap, contexts, prep.context_tangents)...,
         )
-        dy === dy_righttype || copyto!(dy, dy_righttype)
+        copyto!(dy, new_dy)
     end
     return y, ty
 end
